@@ -27,33 +27,33 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-require 'googleauth/signet'
-require 'googleauth/credentials_loader'
-require 'multi_json'
+require "googleauth/signet"
+require "googleauth/credentials_loader"
+require "multi_json"
 
 module Google
   module Auth
     # Small utility for normalizing scopes into canonical form
     module ScopeUtil
       ALIASES = {
-        'email' => 'https://www.googleapis.com/auth/userinfo.email',
-        'profile' => 'https://www.googleapis.com/auth/userinfo.profile',
-        'openid' => 'https://www.googleapis.com/auth/plus.me'
+        "email"   => "https://www.googleapis.com/auth/userinfo.email",
+        "profile" => "https://www.googleapis.com/auth/userinfo.profile",
+        "openid"  => "https://www.googleapis.com/auth/plus.me"
       }.freeze
 
-      def self.normalize(scope)
-        list = as_array(scope)
+      def self.normalize scope
+        list = as_array scope
         list.map { |item| ALIASES[item] || item }
       end
 
-      def self.as_array(scope)
+      def self.as_array scope
         case scope
         when Array
           scope
         when String
-          scope.split(' ')
+          scope.split " "
         else
-          raise 'Invalid scope value. Must be string or array'
+          raise "Invalid scope value. Must be string or array"
         end
       end
     end
